[patch] gcc/config/*: Fix comment typos.

Kazu Hirata kazu@cs.umass.edu
Fri Sep 10 12:48:00 GMT 2004


Hi,

Committed as obvious.

Kazu Hirata

2004-09-10  Kazu Hirata  <kazu@cs.umass.edu>

	* config/darwin.c, config/alpha/alpha.h, config/arm/arm.c,
	config/arm/arm.h, config/arm/arm.md, config/arm/bpabi.h,
	config/arm/predicates.md, config/frv/frv.c, config/frv/frv.md,
	config/h8300/h8300.md, config/i386/gmm_malloc.h,
	config/ia64/ia64.md, config/ip2k/libgcc.S,
	config/mips/mips-ps-3d.md, config/mips/mips.c,
	config/rs6000/rs6000.c, config/s390/s390.c,
	config/sh/symbian.c: Fix comment typos.

Index: config/darwin.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/darwin.c,v
retrieving revision 1.86
diff -u -r1.86 darwin.c
--- config/darwin.c	1 Sep 2004 17:18:00 -0000	1.86
+++ config/darwin.c	10 Sep 2004 11:45:29 -0000
@@ -62,7 +62,7 @@
    are required by consumers of the generated code.  Currently, gdb
    uses this to patch in a jump to the overriding function, this
    allows all uses of the old name to forward to the replacement,
-   including existing function poiinters and virtual methods.  See
+   including existing function pointers and virtual methods.  See
    rs6000_emit_prologue for the code that handles the nop insertions.
  
    The added indirection allows gdb to redirect accesses to static
Index: config/alpha/alpha.h
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/alpha/alpha.h,v
retrieving revision 1.230
diff -u -r1.230 alpha.h
--- config/alpha/alpha.h	27 Aug 2004 00:08:35 -0000	1.230
+++ config/alpha/alpha.h	10 Sep 2004 11:45:30 -0000
@@ -476,7 +476,7 @@
 
    Note that small vector types can get mapped onto integer modes at the
    whim of not appearing in alpha-modes.def.  We never promoted these
-   values before; don't do so now that we've trimed the set of modes to
+   values before; don't do so now that we've trimmed the set of modes to
    those actually implemented in the backend.  */
 
 #define PROMOTE_MODE(MODE,UNSIGNEDP,TYPE)			\
Index: config/arm/arm.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/arm/arm.c,v
retrieving revision 1.402
diff -u -r1.402 arm.c
--- config/arm/arm.c	4 Sep 2004 08:50:36 -0000	1.402
+++ config/arm/arm.c	10 Sep 2004 11:45:36 -0000
@@ -634,7 +634,7 @@
   return count;
 }
 
-/* Set up library functions uqniue to ARM.  */
+/* Set up library functions unique to ARM.  */
 
 static void
 arm_init_libfuncs (void)
@@ -654,7 +654,7 @@
   set_optab_libfunc (neg_optab, DFmode, "__aeabi_dneg");
   set_optab_libfunc (sub_optab, DFmode, "__aeabi_dsub");
 
-  /* Double-precision comparisions.  Table 3.  */
+  /* Double-precision comparisons.  Table 3.  */
   set_optab_libfunc (eq_optab, DFmode, "__aeabi_dcmpeq");
   set_optab_libfunc (ne_optab, DFmode, NULL);
   set_optab_libfunc (lt_optab, DFmode, "__aeabi_dcmplt");
@@ -670,7 +670,7 @@
   set_optab_libfunc (neg_optab, SFmode, "__aeabi_fneg");
   set_optab_libfunc (sub_optab, SFmode, "__aeabi_fsub");
 
-  /* Single-precision comparisions.  Table 5.  */
+  /* Single-precision comparisons.  Table 5.  */
   set_optab_libfunc (eq_optab, SFmode, "__aeabi_fcmpeq");
   set_optab_libfunc (ne_optab, SFmode, NULL);
   set_optab_libfunc (lt_optab, SFmode, "__aeabi_fcmplt");
@@ -693,7 +693,7 @@
   set_conv_libfunc (trunc_optab, SFmode, DFmode, "__aeabi_d2f");
   set_conv_libfunc (sext_optab, DFmode, SFmode, "__aeabi_f2d");
 
-  /* Integer to floating-point converisons.  Table 8.  */
+  /* Integer to floating-point conversions.  Table 8.  */
   set_conv_libfunc (sfloat_optab, DFmode, SImode, "__aeabi_i2d");
   set_conv_libfunc (ufloat_optab, DFmode, SImode, "__aeabi_ui2d");
   set_conv_libfunc (sfloat_optab, DFmode, DImode, "__aeabi_l2d");
@@ -2823,7 +2823,7 @@
     {
       if (flag_function_sections
 	  || DECL_SECTION_NAME (current_function_decl))
-	/* c.3 is handled by the defintion of the
+	/* c.3 is handled by the definition of the
 	   ARM_DECLARE_FUNCTION_SIZE macro.  */
 	return 1;
     }
@@ -12900,7 +12900,7 @@
       return;
     }
 
-  /* Load the pic recister before setting the frame pointer, so we can use r7
+  /* Load the pic register before setting the frame pointer, so we can use r7
      as a temporary work register.  */
   if (flag_pic)
     arm_load_pic_register ();
Index: config/arm/arm.h
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/arm/arm.h,v
retrieving revision 1.256
diff -u -r1.256 arm.h
--- config/arm/arm.h	1 Sep 2004 12:49:30 -0000	1.256
+++ config/arm/arm.h	10 Sep 2004 11:45:38 -0000
@@ -2059,7 +2059,7 @@
 
 /* Set the short-call flag for any function compiled in the current
    compilation unit.  We skip this for functions with the section
-   attirubte when long-calls are in effect as this tells the compiler
+   attribute when long-calls are in effect as this tells the compiler
    that the section might be placed a long way from the caller.
    See arm_is_longcall_p() for more information.  */
 #define ARM_DECLARE_FUNCTION_SIZE(STREAM, NAME, DECL)	\
Index: config/arm/arm.md
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/arm/arm.md,v
retrieving revision 1.181
diff -u -r1.181 arm.md
--- config/arm/arm.md	24 Aug 2004 20:16:34 -0000	1.181
+++ config/arm/arm.md	10 Sep 2004 11:45:41 -0000
@@ -117,7 +117,7 @@
    (VUNSPEC_WCMP_EQ  11) ; Used by the iWMMXt WCMPEQ instructions
    (VUNSPEC_WCMP_GTU 12) ; Used by the iWMMXt WCMPGTU instructions
    (VUNSPEC_WCMP_GT  13) ; Used by the iwMMXT WCMPGT instructions
-   (VUNSPEC_EH_RETURN 20); Use to overrite the return address for exception
+   (VUNSPEC_EH_RETURN 20); Use to override the return address for exception
 			 ; handling.
   ]
 )
Index: config/arm/bpabi.h
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/arm/bpabi.h,v
retrieving revision 1.6
diff -u -r1.6 bpabi.h
--- config/arm/bpabi.h	3 Sep 2004 00:39:59 -0000	1.6
+++ config/arm/bpabi.h	10 Sep 2004 11:45:41 -0000
@@ -33,7 +33,7 @@
    calling convention.  */
 #define FLOAT_LIB_COMPARE_RETURNS_BOOL(MODE, COMPARISON) TARGET_BPABI
 
-/* The BPABI integer comparision routines return { -1, 0, 1 }.  */
+/* The BPABI integer comparison routines return { -1, 0, 1 }.  */
 #define TARGET_LIB_INT_CMP_BIASED !TARGET_BPABI
 
 /* Tell the assembler to build BPABI binaries.  */
Index: config/arm/predicates.md
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/arm/predicates.md,v
retrieving revision 1.2
diff -u -r1.2 predicates.md
--- config/arm/predicates.md	2 Sep 2004 17:52:28 -0000	1.2
+++ config/arm/predicates.md	10 Sep 2004 11:45:41 -0000
@@ -171,7 +171,7 @@
   (and (match_code "plus,minus,ior,xor,and")
        (match_test "mode == GET_MODE (op)")))
 
-;; True for logical binary opertors.
+;; True for logical binary operators.
 (define_special_predicate "logical_binary_operator"
   (and (match_code "ior,xor,and")
        (match_test "mode == GET_MODE (op)")))
Index: config/frv/frv.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/frv/frv.c,v
retrieving revision 1.68
diff -u -r1.68 frv.c
--- config/frv/frv.c	9 Sep 2004 13:48:23 -0000	1.68
+++ config/frv/frv.c	10 Sep 2004 11:45:45 -0000
@@ -8638,7 +8638,7 @@
 
        - Conditional instructions are scheduled on the assumption that
 	 they will be executed.  This is usually a good thing, since it
-	 tends to avoid unncessary stalls in the conditional code.
+	 tends to avoid unnecessary stalls in the conditional code.
 	 But we want to pack conditional instructions as tightly as
 	 possible, in order to optimize the case where they aren't
 	 executed.
@@ -9553,7 +9553,7 @@
 
   /* ACCs and ACCGs are implicity global registers if media instrinsics
      are being used.  We set up this lazily to avoid creating lots of
-     unncessary call_insn rtl in non-media code.  */
+     unnecessary call_insn rtl in non-media code.  */
   for (i = 0; i <= ACC_MASK; i++)
     if ((i & ACC_MASK) == i)
       global_regs[i + ACC_FIRST] = global_regs[i + ACCG_FIRST] = 1;
@@ -9647,7 +9647,7 @@
     }
 
   /* IACCs are implicity global registers.  We set up this lazily to
-     avoid creating lots of unncessary call_insn rtl when IACCs aren't
+     avoid creating lots of unnecessary call_insn rtl when IACCs aren't
      being used.  */
   regno = INTVAL (op) + IACC_FIRST;
   for (i = 0; i < HARD_REGNO_NREGS (regno, mode); i++)
Index: config/frv/frv.md
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/frv/frv.md,v
retrieving revision 1.20
diff -u -r1.20 frv.md
--- config/frv/frv.md	9 Sep 2004 06:33:57 -0000	1.20
+++ config/frv/frv.md	10 Sep 2004 11:45:47 -0000
@@ -477,7 +477,7 @@
 ;;	     X + L when each S''[X] is added.  If so, set S to the
 ;;	     concatenation of S[0]...S[L-1] and S'', then goto (i).
 ;;
-;;	 (h) If (g) found no permuation, abort.
+;;	 (h) If (g) found no permutation, abort.
 ;;
 ;;	 (i) S is now the sorted sequence for this group, meaning that S[X]
 ;;	     issues to unit X.  Trim any unwanted nops from the end of S.
Index: config/h8300/h8300.md
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/h8300/h8300.md,v
retrieving revision 1.286
diff -u -r1.286 h8300.md
--- config/h8300/h8300.md	8 Jul 2004 03:40:33 -0000	1.286
+++ config/h8300/h8300.md	10 Sep 2004 11:45:49 -0000
@@ -5994,7 +5994,7 @@
 	    (match_operand 3 "h8300_src_operand" "")]))
    (set (match_operand 4 "memory_operand" "")
 	(match_dup 0))]
-  "0 /* Disabale because it break compiling fp-bit.c.  */
+  "0 /* Disable because it breaks compiling fp-bit.c.  */
    && TARGET_H8300SX
    && peep2_reg_dead_p (3, operands[0])
    && !reg_overlap_mentioned_p (operands[0], operands[3])
@@ -6024,7 +6024,7 @@
 	(match_operator 3 "h8sx_binary_memory_operator"
 	   [(match_operand 4 "h8300_dst_operand" "")
 	    (match_dup 0)]))]
-  "0 /* Disabale because it break compiling fp-bit.c.  */
+  "0 /* Disable because it breaks compiling fp-bit.c.  */
    && TARGET_H8300SX
    && peep2_reg_dead_p (2, operands[0])
    && !reg_overlap_mentioned_p (operands[0], operands[4])"
Index: config/i386/gmm_malloc.h
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/i386/gmm_malloc.h,v
retrieving revision 1.1
diff -u -r1.1 gmm_malloc.h
--- config/i386/gmm_malloc.h	3 Aug 2004 19:52:48 -0000	1.1
+++ config/i386/gmm_malloc.h	10 Sep 2004 11:45:49 -0000
@@ -47,7 +47,7 @@
     return ((void *) 0);
 
  /* Assume malloc'd pointer is aligned at least to sizeof (void*).
-    If necesary, add another sizeof (void*) to store the value
+    If necessary, add another sizeof (void*) to store the value
     returned by malloc. Effectively this enforces a minimum alignment
     of sizeof double. */     
     if (align < 2 * sizeof (void *))
Index: config/ia64/ia64.md
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/ia64/ia64.md,v
retrieving revision 1.135
diff -u -r1.135 ia64.md
--- config/ia64/ia64.md	18 Aug 2004 21:08:27 -0000	1.135
+++ config/ia64/ia64.md	10 Sep 2004 11:45:51 -0000
@@ -345,7 +345,7 @@
    (and (match_code "const_int")
         (match_test "INTVAL (op) >= 0 && INTVAL (op) < 32")))
 
-;; True if OP is one of the immediate valuse 2, 4, 8, or 16.
+;; True if OP is one of the immediate values 2, 4, 8, or 16.
 (define_predicate "shladd_operand"
   (and (match_code "const_int")
        (match_test "INTVAL (op) == 2 || INTVAL (op) == 4 ||
Index: config/ip2k/libgcc.S
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/ip2k/libgcc.S,v
retrieving revision 1.7
diff -u -r1.7 libgcc.S
--- config/ip2k/libgcc.S	7 Jul 2004 19:24:26 -0000	1.7
+++ config/ip2k/libgcc.S	10 Sep 2004 11:45:51 -0000
@@ -1498,7 +1498,7 @@
 #endif
 
 #if defined(Lwrite)
-	/* Dummy entrypoint to suppress problems with glue code.  */
+	/* Dummy entry point to suppress problems with glue code.  */
 	.sect	.text.libgcc,"ax"
 	.global	_write
 	.func	write, _write
Index: config/mips/mips-ps-3d.md
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/mips/mips-ps-3d.md,v
retrieving revision 1.6
diff -u -r1.6 mips-ps-3d.md
--- config/mips/mips-ps-3d.md	3 Sep 2004 20:12:27 -0000	1.6
+++ config/mips/mips-ps-3d.md	10 Sep 2004 11:45:51 -0000
@@ -277,7 +277,7 @@
    (set_attr "mode" "SF")])
 
 ;----------------------------------------------------------------------------
-; Floating Point Comparisions for Scalars
+; Floating Point Comparisons for Scalars
 ;----------------------------------------------------------------------------
 
 (define_insn "mips_cabs_cond_<fmt>"
@@ -293,7 +293,7 @@
 
 
 ;----------------------------------------------------------------------------
-; Floating Point Comparisions for Four Singles
+; Floating Point Comparisons for Four Singles
 ;----------------------------------------------------------------------------
 
 (define_insn_and_split "mips_c_cond_4s"
@@ -356,7 +356,7 @@
 
 
 ;----------------------------------------------------------------------------
-; Floating Point Comparisions for Paired Singles
+; Floating Point Comparisons for Paired Singles
 ;----------------------------------------------------------------------------
 
 (define_insn "mips_c_cond_ps"
Index: config/mips/mips.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/mips/mips.c,v
retrieving revision 1.467
diff -u -r1.467 mips.c
--- config/mips/mips.c	8 Sep 2004 18:45:07 -0000	1.467
+++ config/mips/mips.c	10 Sep 2004 11:45:56 -0000
@@ -1935,7 +1935,7 @@
 
 	 Given the choice between "li R1,0...255" and "move R1,R2"
 	 (where R2 is a known constant), it is usually better to use "li",
-	 since we do not want to unnessarily extend the lifetime of R2.  */
+	 since we do not want to unnecessarily extend the lifetime of R2.  */
       if (outer_code == SET
 	  && INTVAL (x) >= 0
 	  && INTVAL (x) < 256)
@@ -9604,7 +9604,7 @@
 /* Expand a __builtin_mips_movt_*_ps() or __builtin_mips_movf_*_ps()
    function (TYPE says which).  ARGLIST is the list of arguments to the
    function, ICODE is the instruction that should be used to compare
-   the first two arguments, and COND is the conditon it should test.
+   the first two arguments, and COND is the condition it should test.
    TARGET, if nonnull, suggests a good place to put the result.  */
 
 static rtx
Index: config/rs6000/rs6000.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/rs6000/rs6000.c,v
retrieving revision 1.706
diff -u -r1.706 rs6000.c
--- config/rs6000/rs6000.c	8 Sep 2004 23:19:58 -0000	1.706
+++ config/rs6000/rs6000.c	10 Sep 2004 11:46:03 -0000
@@ -17188,7 +17188,7 @@
     case MEM:
       /* When optimizing for size, MEM should be slightly more expensive
 	 than generating address, e.g., (plus (reg) (const)).
-	 L1 cache latecy is about two instructions.  */
+	 L1 cache latency is about two instructions.  */
       *total = optimize_size ? COSTS_N_INSNS (1) + 1 : COSTS_N_INSNS (2);
       return true;
 
Index: config/s390/s390.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/s390/s390.c,v
retrieving revision 1.173
diff -u -r1.173 s390.c
--- config/s390/s390.c	25 Aug 2004 09:52:23 -0000	1.173
+++ config/s390/s390.c	10 Sep 2004 11:46:06 -0000
@@ -2543,7 +2543,7 @@
   return FALSE;
 }
 
-/* Return 1 if it is valid *and* preferrable to use LA to
+/* Return 1 if it is valid *and* preferable to use LA to
    compute the sum of OP1 and OP2.  */
 
 int
Index: config/sh/symbian.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/sh/symbian.c,v
retrieving revision 1.2
diff -u -r1.2 symbian.c
--- config/sh/symbian.c	20 Jul 2004 12:26:02 -0000	1.2
+++ config/sh/symbian.c	10 Sep 2004 11:46:06 -0000
@@ -230,8 +230,8 @@
      /* Remove DLL_IMPORT_PREFIX.
 	Note - we do not issue a warning here.  In Symbian's environment it
 	is legitimate for a prototype to be marked as dllimport and the
-	corresponding defintion to be marked as dllexport.  The prototypes
-	are in headers used everywhere and the defintion is in a translation
+	corresponding definition to be marked as dllexport.  The prototypes
+	are in headers used everywhere and the definition is in a translation
 	unit which has included the header in order to ensure argument
 	correctness.  */
       oldname += strlen (DLL_IMPORT_PREFIX);
@@ -448,8 +448,8 @@
 	}
     }
 
-  /* If the node is an overloaded constructor or desctructor, then we must
-     make sure that the attribute is propogated along the overload chain,
+  /* If the node is an overloaded constructor or destructor, then we must
+     make sure that the attribute is propagated along the overload chain,
      as it is these overloaded functions which will be emitted, rather than
      the user declared constructor itself.  */
   if (TREE_CODE (TREE_TYPE (node)) == METHOD_TYPE
@@ -488,7 +488,7 @@
 
 	  symbian_add_attribute (function, attr);
 
-	  /* Propogate the attribute to any function thunks as well.  */
+	  /* Propagate the attribute to any function thunks as well.  */
 	  for (thunk = DECL_THUNKS (function); thunk; thunk = TREE_CHAIN (thunk))
 	    if (TREE_CODE (thunk) == FUNCTION_DECL)
 	      symbian_add_attribute (thunk, attr);
@@ -497,7 +497,7 @@
 
   if (TREE_CODE (node) == FUNCTION_DECL && DECL_VIRTUAL_P (node))
     {
-      /* Propogate the attribute to any thunks of this function.  */
+      /* Propagate the attribute to any thunks of this function.  */
       for (thunk = DECL_THUNKS (node); thunk; thunk = TREE_CHAIN (thunk))
 	if (TREE_CODE (thunk) == FUNCTION_DECL)
 	  symbian_add_attribute (thunk, attr);
@@ -879,7 +879,7 @@
   return import_export;
 }
 
 /* Dummy defintion of this array for cc1 building purposes.  */
 tree cp_global_trees[CPTI_MAX] __attribute__((weak));
 
 #if defined ENABLE_TREE_CHECKING && (GCC_VERSION >= 2007)
@@ -879,7 +879,7 @@
 }
 
-/* Dummy defintion of this array for cc1 building purposes.  */
+/* Dummy definition of this array for cc1 building purposes.  */
 tree cp_global_trees[CPTI_MAX] __attribute__((weak));
 



More information about the Gcc-patches mailing list